%define api 5
%define major 5
%define oname qt5

%define module qtscript

%define qtscript %mklibname qt%{api}script %{major}
%define qtscriptd %mklibname qt%{api}script -d
%define qtscripttools %mklibname qt%{api}scripttools %{major}
%define qtscripttoolsd %mklibname qt%{api}scripttools -d

# Requires qdoc5 and qt5-tools to build
%bcond_with docs

Summary:	Version 5 of the Qt toolkit (%{module} packages)
Name:		qt5-%{module}
Version:	5.9.4
Release:	1
License:	LGPLv3+
Group:		Development/KDE and Qt
Url:		http://qt-project.org/
Source0:	http://ftp.fau.de/qtproject/official_releases/qt/%(echo %{version} |cut -d. -f1-2)/%{version}/submodules/%{module}-opensource-src-%{version}.tar.xz
Source100:	%{name}.rpmlintrc
BuildRequires:	pkgconfig(Qt5Core) >= %{version}
BuildRequires:	pkgconfig(Qt5Gui) >= %{version}
BuildRequires:	pkgconfig(Qt5Widgets) >= %{version}
%if %{with docs}
BuildRequires:	qdoc5
BuildRequires:	qt5-tools
%endif

%description
Version 5 of the Qt toolkit (%{module} packages).

#----------------------------------------------------------------------------

%package -n %{qtscript}
Summary:	Qt Script runtime library
Group:		System/Libraries
Suggests:	qt5-qtscript-i18n

%description -n %{qtscript}
Qt Script runtime library.

%files -n %{qtscript}
%{_qt5_libdir}/libQt%{api}Script.so.%{major}*
%if "%{_qt5_libdir}" != "%{_libdir}"
%{_libdir}/libQt%{api}Script.so.%{major}*
%endif

#----------------------------------------------------------------------------

%package -n %{qtscriptd}
Summary:	Development files for Qt Script
Group:		Development/KDE and Qt
Requires:	%{qtscript} = %{EVRD}
Requires:	qmake%{api}
Conflicts:	qmake5 < 5.6.0

%description -n %{qtscriptd}
Development files for Qt Script.

%files -n %{qtscriptd}
%{_qt5_includedir}/QtScript
%{_qt5_libdir}/libQt%{api}Script.so
%{_qt5_libdir}/libQt%{api}Script.prl
%{_qt5_libdir}/cmake/Qt%{api}Script
%{_qt5_libdir}/pkgconfig/Qt%{api}Script.pc
%if "%{_qt5_libdir}" != "%{_libdir}"
%{_libdir}/pkgconfig/Qt%{api}Script.pc
%endif
%{_qt5_prefix}/mkspecs/modules/qt_lib_script.pri
%{_qt5_prefix}/mkspecs/modules/qt_lib_script_private.pri

#----------------------------------------------------------------------------

%package -n %{qtscripttools}
Summary:	Qt Script tools library
Group:		System/Libraries

%description -n %{qtscripttools}
Qt Script tools library.

%files -n %{qtscripttools}
%{_qt5_libdir}/libQt%{api}ScriptTools.so.%{major}*
%if "%{_qt5_libdir}" != "%{_libdir}"
%{_libdir}/libQt%{api}ScriptTools.so.%{major}*
%endif

#----------------------------------------------------------------------------

%package -n %{qtscripttoolsd}
Summary:	Development files for Qt Script tools
Group:		Development/KDE and Qt
Requires:	%{qtscripttools} = %{EVRD}
Requires:	qmake%{api}
Conflicts:	qmake5 < 5.6.0

%description -n %{qtscripttoolsd}
Development files for Qt Script tools.

%files -n %{qtscripttoolsd}
%{_qt5_includedir}/QtScriptTools
%{_qt5_libdir}/libQt%{api}ScriptTools.so
%{_qt5_libdir}/libQt%{api}ScriptTools.prl
%{_qt5_libdir}/cmake/Qt%{api}ScriptTools
%{_qt5_libdir}/pkgconfig/Qt%{api}ScriptTools.pc
%if "%{_qt5_libdir}" != "%{_libdir}"
%{_libdir}/pkgconfig/Qt%{api}ScriptTools.pc
%endif
%{_qt5_prefix}/mkspecs/modules/qt_lib_scripttools.pri
%{_qt5_prefix}/mkspecs/modules/qt_lib_scripttools_private.pri

#----------------------------------------------------------------------------

%if %{with docs}
%package doc
Summary:	Qt QCH documentation for %{name}
Group:		Documentation
Conflicts:	qt5-doc < 5.6.0
BuildArch:	noarch

%description doc
Qt QCH documentation for %{name}.

%files doc
%{_qt5_docdir}/qtscript.qch
%{_qt5_docdir}/qtscripttools.qch
%endif

#----------------------------------------------------------------------------

%package examples
Summary:	Example applications for %{name}
Group:		Development/KDE and Qt
Conflicts:	qt5-examples < 5.6.0

%description examples
Example applications for %{name}.

%files examples
%{_qt5_exampledir}/script/

#----------------------------------------------------------------------------

%prep
%setup -qn %{module}-opensource-src-%{version}

%build
%qmake_qt5
%make STRIP=true

%if %{with docs}
%make docs
%endif

%install
make install STRIP=true INSTALL_ROOT=%{buildroot}

%if %{with docs}
make install_qch_docs INSTALL_ROOT=%{buildroot}
%endif

%if "%{_qt5_libdir}" != "%{_libdir}"
pushd %{buildroot}%{_libdir}
ln -s ../%{_lib}/qt%{api}/%{_lib}/*.so.* .
mkdir pkgconfig
cd pkgconfig
ln -s ../../%{_lib}/qt%{api}/%{_lib}/pkgconfig/*.pc .
popd
%endif

# QMAKE_PRL_BUILD_DIR = /builddir/build/BUILD/qt-everywhere-opensource-src-5.4.0-beta/qtwayland/src/client
## .prl/.la file love
# nuke .prl reference(s) to %%buildroot, excessive (.la-like) libs
pushd %{buildroot}%{_qt5_libdir}
for prl_file in libQt5*.prl ; do
  sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" ${prl_file}
  if [ -f "$(basename ${prl_file} .prl).so" ]; then
    rm -fv "$(basename ${prl_file} .prl).la"
    sed -i -e "/^QMAKE_PRL_LIBS/d" ${prl_file}
  fi
done
popd

%changelog

* Wed Jan 24 2018 Andrey Bondrov <andrey.bondrov@rosalab.ru> 5.9.4-1
- (b3cd891) New version 5.9.4


